@@ -1,35 +1,13 @@
 /*
-  Copyright (c) 2003 Andreas Gungl <a.gungl@gmx.de>
+  SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-
-  In addition, as a special exception, the copyright holders give
-  permission to link the code of this program with any edition of
-  the Qt library by Trolltech AS, Norway (or with modified versions
-  of Qt that use the same license as Qt), and distribute linked
-  combinations including the two.  You must obey the GNU General
-  Public License in all respects for all of the code used other than
-  Qt.  If you modify this file, you may extend this exception to
-  your version of the file, but you are not obligated to do so.  If
-  you do not wish to do so, delete this exception statement from
-  your version.
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filterlog.h"
 
-#include "messagecomposer/util.h"
 #include "mailcommon_debug.h"
+#include "messagecomposer/util.h"
 
 #include <QFile>
 #include <QTime>
@@ -44,11 +22,7 @@ public:
     Private(FilterLog *qq)
         : q(qq)
         , mMaxLogSize(512 * 1024)
-        , mAllowedTypes(FilterLog::Meta
-                        |FilterLog::PatternDescription
-                        |FilterLog::RuleResult
-                        |FilterLog::PatternResult
-                        |FilterLog::AppliedAction)
+        , mAllowedTypes(FilterLog::Meta | FilterLog::PatternDescription | FilterLog::RuleResult | FilterLog::PatternResult | FilterLog::AppliedAction)
     {
     }
 
@@ -67,8 +41,7 @@ public:
 void FilterLog::Private::checkLogSize()
 {
     if (mCurrentLogSize > mMaxLogSize && mMaxLogSize > -1) {
-        qCDebug(MAILCOMMON_LOG) << "Filter log: memory limit reached, starting to discard old items, size ="
-                                << QString::number(mCurrentLogSize);
+        qCDebug(MAILCOMMON_LOG) << "Filter log: memory limit reached, starting to discard old items, size =" << QString::number(mCurrentLogSize);
 
         // avoid some kind of hysteresis, shrink the log to 90% of its maximum
         while (mCurrentLogSize > (mMaxLogSize * 0.9)) {
